pub struct ActionMap(pub IndexMap<ActionId, ManifestAction>);Expand description
Ordered map of actions defined within the plugin
Keys must be unique to each action following the [a-zA-Z_-] format (i.e example_action, my-action, MyAction)
Tuple Fields
0: IndexMap<ActionId, ManifestAction>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ActionMap
impl<'de> Deserialize<'de> for ActionMap
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ActionMap
impl JsonSchema for ActionMap
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Validate for ActionMap
impl Validate for ActionMap
Sourcefn validate_into(
&self,
ctx: &(),
parent: &mut dyn FnMut() -> Path,
report: &mut Report,
)
fn validate_into( &self, ctx: &(), parent: &mut dyn FnMut() -> Path, report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.Auto Trait Implementations
impl Freeze for ActionMap
impl RefUnwindSafe for ActionMap
impl Send for ActionMap
impl Sync for ActionMap
impl Unpin for ActionMap
impl UnsafeUnpin for ActionMap
impl UnwindSafe for ActionMap