pub struct BinaryNodeVersion(pub Range);Expand description
Version range of a node runtime, it’s recommended that you leave this as the default unless you explicitly need a specific version and its features
Tuple Fields
0: RangeTrait Implementations
Sourceimpl AsRef<Range> for BinaryNodeVersion
impl AsRef<Range> for BinaryNodeVersion
Sourceimpl Clone for BinaryNodeVersion
impl Clone for BinaryNodeVersion
Sourcefn clone(&self) -> BinaryNodeVersion
fn clone(&self) -> BinaryNodeVersion
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BinaryNodeVersion
impl Debug for BinaryNodeVersion
Sourceimpl<'de> Deserialize<'de> for BinaryNodeVersion
impl<'de> Deserialize<'de> for BinaryNodeVersion
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BinaryNodeVersion
impl JsonSchema for BinaryNodeVersion
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BinaryNodeVersion
impl PartialEq for BinaryNodeVersion
Sourceimpl Serialize for BinaryNodeVersion
impl Serialize for BinaryNodeVersion
impl Eq for BinaryNodeVersion
impl StructuralPartialEq for BinaryNodeVersion