pub struct MBinNode {
pub entrypoint: String,
pub version: BinaryNodeVersion,
}Expand description
Node “binary” which uses a node runtime to execute the js script
at the provided entrypoint
Fields
entrypoint: StringEntrypoint for the program
e.g bin/index.js
version: BinaryNodeVersionVersion of node the program should run using.
It’s recommended that you leave this as the default unless you explicitly need a specific version and its features